@@ -9,7 +9,7 @@ import time
 #configParser = configparser.RawConfigParser()
 path = os.environ.get('ND_HOME')
 path = path + '/config/ndsettings.conf'
-print("path of  NDC config : ",path )
+print("path of  NDC config : ",path)
 #configParser.read(path)
 #path_for_insProfile = configParser.get('PYTHON_AGENT', 'path_profile')
 myvars = {}
@@ -40,20 +40,20 @@ class MethodInterceptor(ExitCallInterceptor):
         if len(self.cls.__package__) >= 1:
             fqmforentry = str(self.cls.__package__) + "." + str(self.cls.__name__) + "." + str(original_method.__name__)
         else:
-            fqmforentry = "defaultpackage." + str(self.cls.__name__) + "." + str(original_method.__name__)
+            #fqmforentry = "_." + str(self.cls.__name__) + "." + str(original_method.__name__)
+            fqmforentry = "." + str(self.cls.__name__) + "." + str(original_method.__name__)
 
-
-        print("Inside custom method")
+        # print("Inside custom method")
 
         before_time = time.time_ns() // 1000000
 
-        print("Before applying method call delay")
-        print("FQM: ", fqmforentry)
+        # print("Before applying method call delay")
+        # print("FQM: ", fqmforentry)
 
-        from pythonagent.agent.probes.havoc.havoc_manager import NDNetHavocMonitor
+        from pythonagent.agent.probes.havoc.havoc_manager import NDNetHavocMonitor, NDHavocException
         havoc_monitor = NDNetHavocMonitor.get_instance()
 
-        havoc_monitor.apply_method_invocation_failure(fqmforentry)
+        # havoc_monitor.apply_method_invocation_failure(fqmforentry)
 
         method = None
         if bt is not None:
@@ -65,15 +65,28 @@ class MethodInterceptor(ExitCallInterceptor):
 
                 havoc_monitor.apply_method_call_delay(fqmforentry)
 
+            except Exception as e:
+                self.agent.logger.exception('Modulename: MethodInterceptor class inside _custom_method got exception in orginal method')
+                raise e  # Added by Samanvay on 06/04/2022 while debugging outbound havoc failure main -> http_callout -> request.get
+
+            finally:
+
                 after_time = time.time_ns() // 1000000
                 duration = after_time - before_time
                 print("Duration Calculated: ", duration)
 
+                try:
+                    havoc_monitor.apply_method_invocation_failure(fqmforentry)
+                except Exception as e:
+                    if isinstance(e, NDHavocException):
+                        print("Havoc Exception {}".format(e))
+                        status = 503
+                        self.agent.method_exit(bt, fqmforentry, status, duration)
+                        self.agent.set_current_status_code(503)
+                        raise e
+                    else:
+                        print("Non-Havoc Exception {}".format(e))
 
-            except:
-                self.agent.logger.exception('Modulename: MethodInterceptor class inside _custom_method got exception in orginal method')
-
-            finally:
                 status = 0  # Needed for callouts only
                 if self.agent.cav_env == "AWS_LAMBDA":
                     self.agent.method_exit(bt, fqmforentry, status, duration)
@@ -86,7 +99,7 @@ class MethodInterceptor(ExitCallInterceptor):
                     if self.agent.cav_env == "NATIVE":
                         self.agent.method_exit(bt, fqmforentry)
         else:
-            #self.agent.logger.info("did not find BT in ModuleInterceptor._custom_method")
+            # self.agent.logger.info("did not find BT in ModuleInterceptor._custom_method")
             self.agent.logger.exception('Modulename: MethodInterceptor class inside _custom_method,,did not find BT in ModuleInterceptor._custom_method')
             response = original_method(*args, **kwargs)
         return response 
