@@ -39,32 +39,29 @@ class NDNetHavocRequest(object):
             # self.delayInSec = havoc_conf.delayInSec
             self.delayInSec = havoc_conf.delayInSec / 1000  # UI is sending in milliseconds
 
-
         if hasattr(havoc_conf, 'hostname'):
             self.hostname = havoc_conf.hostname
 
         self.startTime = time.time_ns() // 1000000
-        self.applying = False
         self.header_dict = header_dict
+        self.nhmid = header_dict["NHMID"]
+
         self.totalDurationInSec = havoc_conf.totalDurationInSec
 
         try:
-            self.memoryLeaksInSec = havoc_conf.memoryLeaksInSec
-            self.leaksINMB = havoc_conf.leaksINMB
             self.enable = havoc_conf.enable
             self.bTName = havoc_conf.bTName
             self.isHavocEnable = False
             self.threshOld = havoc_conf.threshOld
             self.protocol = havoc_conf.protocol
-            #self.memoryLeaksInSec = havoc_conf.memoryLeaksInSec
+            self.leaksINMB = havoc_conf.leaksINMB
+            self.memoryLeaksInSec = havoc_conf.memoryLeaksInSec
             self.backendName = havoc_conf.backendName
 
         except Exception as e:
             self.logger.warning(e)
 
 
-
-
 class NDNetHavocMonitor(object):
 
     __instance = None
@@ -94,10 +91,8 @@ class NDNetHavocMonitor(object):
                 "Custom_Memory_Leak": []
             }
 
-            self.is_parsed = False
             self.logger = logging.getLogger('pythonagent.agent')
 
-
     def set_enable_net_havoc(self, enable_logs_net_havoc):
         try:
             if enable_logs_net_havoc == 1:
@@ -234,87 +229,11 @@ class NDNetHavocMonitor(object):
                     self.logger.debug("memoryLeaksInSec validated")
         else:
             self.logger.debug("leaksINMB, memoryLeaksInSec not needed")
-        # 1.InBoundServicdelayhavoc
-        # 2.InBoundServicefailhavoc
-        # 3.OutBoundServicedelayhavoc
-        # 4 OutBoundServicefailhavoc
-        # 5.MethoCalldelayHavoc
-        # 6.MethodInvocationfailhavoc
-        # 7.Increasememoryusagehavoc
-        # 8.IncreaseCPUutilization
 
         is_valid = True
         return_message = "Config Validated"
         return is_valid, return_message
 
-    def validate_config_new(self, havoc_conf):
-        self.logger.info("Validating config")
-
-        valid_dict = {
-            "enable": False,
-            "havocType": False,
-            "totalDurationInSec": False
-        }
-
-        try:
-            if havoc_conf.enable in [0, 1]:
-                valid_dict["enable"] = True
-
-            if havoc_conf.havocType in [1, 2, 3, 4, 5, 6, 7, 8]:
-                valid_dict["havocType"] = True
-
-            if isinstance(havoc_conf.totalDurationInSec, int):
-                valid_dict["totalDurationInSec"] = True
-
-            havoc_type = havoc_conf.havocType
-
-            if havoc_type in [1, 2]:
-                valid_dict["uRL"] = False
-                if len(havoc_conf.uRL) != 0:
-                    valid_dict["uRL"] = True
-
-            if havoc_type in [3, 4]:
-                valid_dict["hostname"] = False
-                if havoc_conf.backendNameMod != 0:
-                    if len(havoc_conf.hostname) != 0:
-                        valid_dict["hostname"] = True
-                else:
-                    valid_dict["hostname"] = True
-
-            if havoc_type in [5, 6]:
-                valid_dict["methodFQM"] = False
-                if len(havoc_conf.methodFQM) != 0:
-                    valid_dict["methodFQM"] = True
-
-            if havoc_type in [1, 3, 5]:
-                valid_dict["delayInSec"] = False
-                if isinstance(havoc_conf.delayInSec, int):
-                    valid_dict["delayInSec"] = True
-
-            if havoc_type in [7]:
-                valid_dict["leaksINMB"] = False
-                if isinstance(havoc_conf.leaksINMB, int):
-                    valid_dict["leaksINMB"] = True
-                valid_dict["memoryLeaksInSec"] = False
-                if isinstance(havoc_conf.memoryLeaksInSec, int):
-                    valid_dict["memoryLeaksInSec"] = True
-
-            is_valid = True
-            return_message = "Config Validated"
-
-            for k in valid_dict:
-                if not valid_dict[k]:
-                    is_valid = False
-                    return_message = str(k) + " invalid"
-                    break
-
-            return is_valid, return_message
-
-        except Exception as e:
-            self.logger.debug(e)
-            return False, e
-
-    # def parse_nethavoc_config(self, json_conf, havoc_type, header_dict):
     def parse_nethavoc_config(self, json_conf, header_dict):
         self.logger.info("Parsing config")
 
@@ -322,13 +241,28 @@ class NDNetHavocMonitor(object):
             havoc_conf = json.loads(json_conf, object_hook=lambda d: namedtuple('X', d.keys())(*d.values()))
             havoc_type = havoc_conf.havocType
             self.logger.info("Havoc type: {}".format(havoc_type))
+            self.logger.debug("header_dict: {}".format(header_dict))
+            nhmid = header_dict["NHMID"]
+            self.logger.debug("nhmid: {}".format(nhmid))
+
+
+            self.logger.info("checking if havoc already exists")
+
+            havoc_type_full_str = havoc_types[havoc_type]
+            config_list = self.netHavocConfigMap[havoc_type_full_str]
+            self.logger.info("config_list: {}".format(config_list))
+
+            if config_list:
+                for config in config_list:
+                    if nhmid == config.nhmid:
+                        self.logger.info("havoc already exists skipping")
+                        return
 
             is_valid, ret_message = self.validate_config(havoc_conf)
 
             if is_valid:
                 self.logger.info(ret_message)
                 req_obj = NDNetHavocRequest(havoc_conf, header_dict)
-                self.is_parsed = True
 
                 havoc_type_full_str = havoc_types[havoc_type]
                 self.netHavocConfigMap[havoc_type_full_str].append(req_obj)
@@ -337,13 +271,10 @@ class NDNetHavocMonitor(object):
             else:
                 self.logger.info("Invalid config: {}".format(ret_message))
 
-            if havoc_type == 7:
-                self.increase_memory_usage()
-        
         except Exception as e:
+            self.logger.error("havoc parsing exception: {}".format(e))
             raise e
 
-        return self.is_parsed
 
     def common_delay_in_response(self, total_duration_in_sec):
         self.logger.info("Applying delay duration(sec): {}".format(total_duration_in_sec))
@@ -385,11 +316,6 @@ class NDNetHavocMonitor(object):
         if config_list:
             for config in config_list:
 
-                if config.applying:
-                    self.logger.debug("Already applying, not proceeding further")
-                    return
-                config.applying = True
-
                 url = config.uRL
                 delay_in_second = config.delayInSec
 
@@ -407,7 +333,6 @@ class NDNetHavocMonitor(object):
                         self.common_delay_in_response(delay_in_second)
                     else:
                         self.logger.debug("Config not matched for Request URL {}".format(req_url))
-                config.applying = False
 
         else:
             self.logger.debug("config not set for apply_inbound_service_delay")
@@ -418,11 +343,6 @@ class NDNetHavocMonitor(object):
 
         if config_list:
             for config in config_list:
-                if config.applying:
-                    self.logger.debug("Already applying, not proceeding further")
-                    return
-                config.applying = True
-
                 url = config.uRL
 
                 apply_all = False
@@ -432,16 +352,13 @@ class NDNetHavocMonitor(object):
 
                 if apply_all:
                     self.logger.debug("bTNameMode = 0, applying")
-                    config.applying = False
                     self.common_failure(url)
                 else:
                     if url in req_url:
                         self.logger.debug("Config matched for Request URL {}".format(req_url))
-                        config.applying = False
                         self.common_failure(url)
                     else:
                         self.logger.debug("Config not matched for Request URL {}".format(req_url))
-                        config.applying = False
 
 
 
@@ -455,11 +372,6 @@ class NDNetHavocMonitor(object):
 
         if config_list:
             for config in config_list:
-                if config.applying:
-                    self.logger.debug("Already applying, not proceeding further")
-                    return
-
-                config.applying = True
                 hostname = config.hostname
                 delay_in_second = config.delayInSec
 
@@ -477,7 +389,6 @@ class NDNetHavocMonitor(object):
                         self.common_delay_in_response(delay_in_second)
                     else:
                         self.logger.debug("Config not matched for Request Hostname {}".format(req_hostname))
-                config.applying = False
         else:
             self.logger.debug("config not set for apply_outbound_service_delay")
             # raise Exception("config not set for apply_outbound_service_delay")
@@ -488,10 +399,6 @@ class NDNetHavocMonitor(object):
 
         if config_list:
             for config in config_list:
-                if config.applying:
-                    self.logger.debug("Already applying, not proceeding further")
-                    return
-                config.applying = True
 
                 hostname = config.hostname
 
@@ -502,16 +409,13 @@ class NDNetHavocMonitor(object):
 
                 if apply_all:
                     self.logger.debug("backendNameMod = 0, applying")
-                    config.applying = False
                     self.self.common_failure(hostname)
                 else:
                     if hostname in req_hostname:
                         self.logger.debug("Config matched for Request Hostname {}".format(req_hostname))
-                        config.applying = False
                         self.common_failure(hostname)
                     else:
                         self.logger.debug("Config not matched for Request Hostname {}".format(req_hostname))
-                        config.applying = False
 
         else:
             self.logger.debug("config not set for apply_outbound_service_failure")
@@ -523,10 +427,6 @@ class NDNetHavocMonitor(object):
 
         if config_list:
             for config in config_list:
-                if config.applying:
-                    self.logger.debug("Already applying, not proceeding further")
-                    return
-                config.applying = True
 
                 delay_in_second = config.delayInSec
                 method_fqm = config.methodFQM
@@ -536,7 +436,6 @@ class NDNetHavocMonitor(object):
                     self.common_delay_in_response(delay_in_second)
                 else:
                     self.logger.debug("Config not matched for Request FQM {}".format(req_method_fqm))
-                config.applying = False
         else:
             self.logger.debug("config not set for apply_method_call_delay")
             # raise Exception("config not set for apply_method_call_delay")
@@ -547,20 +446,12 @@ class NDNetHavocMonitor(object):
 
         if config_list:
             for config in config_list:
-                if config.applying:
-                    self.logger.debug("Already applying, not proceeding further")
-                    return
-                config.applying = True
-
                 method_fqm = config.methodFQM
-                # if method_fqm == req_method_fqm:
                 if method_fqm in req_method_fqm:
                     self.logger.debug("Config matched for Request FQM {}".format(req_method_fqm))
-                    config.applying = False
                     self.common_failure(method_fqm)
                 else:
                     self.logger.debug("Config not matched for Request FQM {}".format(req_method_fqm))
-                    config.applying = False
 
         else:
             self.logger.debug("config not set for apply_method_call_failure")
@@ -571,16 +462,11 @@ class NDNetHavocMonitor(object):
         config_list = self.netHavocConfigMap["Custom_Memory_Leak"]
         if config_list:
             for config in config_list:
-                if config.applying:
-                    self.logger.debug("Already applying, not proceeding further")
-                    return
-                config.applying = True
 
                 leaksINMB = config.leaksINMB
                 totalDurationInSec = config.totalDurationInSec
                 memoryLeaksInSec = config.memoryLeaksInSec
                 apply_memory_leak(leaksINMB, totalDurationInSec, memoryLeaksInSec)
-                config.applying = False
 
         else:
             self.logger.debug("config not set for apply_method_call_failure")
